==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TodayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TodayExpressionDescription } from "./TodayExpressionDescription";
/**
 * @hidden
 */
var TodayExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TodayExpressionDescriptionMetadata, _super);
    function TodayExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TodayExpressionDescriptionMetadata.b = function (a) {
        if (TodayExpressionDescriptionMetadata.a == null) {
            TodayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TodayExpressionDescriptionMetadata.c(TodayExpressionDescriptionMetadata.a);
        }
        if (a.j(TodayExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(TodayExpressionDescriptionMetadata.a);
    };
    TodayExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    TodayExpressionDescriptionMetadata.d = function (a) {
        TodayExpressionDescriptionMetadata.b(a);
        a.aa("TodayExpression", function () { return new TodayExpressionDescription(); });
        a.z("TodayExpression", TodayExpressionDescriptionMetadata.a);
    };
    TodayExpressionDescriptionMetadata.$t = markType(TodayExpressionDescriptionMetadata, 'TodayExpressionDescriptionMetadata');
    TodayExpressionDescriptionMetadata.a = null;
    return TodayExpressionDescriptionMetadata;
}(Base));
export { TodayExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/TodayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TodayExpressionDescription } from "./TodayExpressionDescription";
/**
 * @hidden
 */
var TodayExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TodayExpressionDescriptionMetadata, _super);
    function TodayExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TodayExpressionDescriptionMetadata.b = function (a) {
        if (TodayExpressionDescriptionMetadata.a == null) {
            TodayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TodayExpressionDescriptionMetadata.c(TodayExpressionDescriptionMetadata.a);
        }
        if (a.k(TodayExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(TodayExpressionDescriptionMetadata.a);
    };
    TodayExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    TodayExpressionDescriptionMetadata.d = function (a) {
        TodayExpressionDescriptionMetadata.b(a);
        a.ac("TodayExpression", function () { return new TodayExpressionDescription(); });
        a.ab("TodayExpression", TodayExpressionDescriptionMetadata.a);
    };
    TodayExpressionDescriptionMetadata.$t = markType(TodayExpressionDescriptionMetadata, 'TodayExpressionDescriptionMetadata');
    TodayExpressionDescriptionMetadata.a = null;
    return TodayExpressionDescriptionMetadata;
}(Base));
export { TodayExpressionDescriptionMetadata };
